@@ -282,7 +282,7 @@ typedef struct {
 	buffer *ssl_verifyclient_username;
 	unsigned short ssl_verifyclient_export_cert;
 
-	unsigned short use_ipv6;
+	unsigned short use_ipv6, set_v6only; /* set_v6only is only a temporary option */
 	unsigned short defer_accept;
 	unsigned short is_ssl;
 	unsigned short allow_http11;
@@ -431,7 +431,6 @@ typedef struct {
 
 #ifdef USE_OPENSSL
 	SSL *ssl;
-	buffer *ssl_error_want_reuse_buffer;
 # ifndef OPENSSL_NO_TLSEXT
 	buffer *tlsext_server_name;
 # endif
