@@ -82,6 +82,11 @@ static int connection_del(server *srv, connection *con) {
 
 	if (-1 == con->ndx) return -1;
 
+	buffer_reset(con->uri.authority);
+	buffer_reset(con->uri.path);
+	buffer_reset(con->uri.query);
+	buffer_reset(con->request.orig_uri);
+
 	i = con->ndx;
 
 	/* not last element */
@@ -305,6 +310,8 @@ static int connection_handle_read_ssl(server *srv, connection *con) {
 		/* the other end close the connection -> KEEP-ALIVE */
 
 		return -2;
+	} else {
+		joblist_append(srv, con);
 	}
 
 	return 0;
@@ -315,6 +322,7 @@ static int connection_handle_read_ssl(server *srv, connection *con) {
 #endif
 }
 
+/* 0: everything ok, -1: error, -2: con closed */
 static int connection_handle_read(server *srv, connection *con) {
 	int len;
 	buffer *b;
@@ -1169,21 +1177,25 @@ found_header_end:
 	return 0;
 }
 
-static handler_t connection_handle_fdevent(void *s, void *context, int revents) {
-	server     *srv = (server *)s;
+static handler_t connection_handle_fdevent(server *srv, void *context, int revents) {
 	connection *con = context;
 
 	joblist_append(srv, con);
 
-	if (revents & FDEVENT_IN) {
-		con->is_readable = 1;
-#if 0
-		log_error_write(srv, __FILE__, __LINE__, "sd", "read-wait - done", con->fd);
-#endif
-	}
-	if (revents & FDEVENT_OUT) {
-		con->is_writable = 1;
-		/* we don't need the event twice */
+	if (con->conf.is_ssl) {
+		/* ssl may read and write for both reads and writes */
+		if (revents & (FDEVENT_IN | FDEVENT_OUT)) {
+			con->is_readable = 1;
+			con->is_writable = 1;
+		}
+	} else {
+		if (revents & FDEVENT_IN) {
+			con->is_readable = 1;
+		}
+		if (revents & FDEVENT_OUT) {
+			con->is_writable = 1;
+			/* we don't need the event twice */
+		}
 	}
 
 
@@ -1694,7 +1706,7 @@ int connection_state_machine(server *srv, connection *con) {
 										ssl_r, ret,
 										ERR_error_string(err, NULL));
 							} while((err = ERR_get_error()));
-						} else {
+						} else if (errno != 0) { /* ssl bug (see lighttpd ticket #2213): sometimes errno == 0 */
 							log_error_write(srv, __FILE__, __LINE__, "sddds", "SSL (error):",
 									ssl_r, ret, errno,
 									strerror(errno));
@@ -1780,7 +1792,7 @@ int connection_state_machine(server *srv, connection *con) {
 	case CON_STATE_READ_POST:
 	case CON_STATE_READ:
 	case CON_STATE_CLOSE:
-		fdevent_event_add(srv->ev, &(con->fde_ndx), con->fd, FDEVENT_IN);
+		fdevent_event_set(srv->ev, &(con->fde_ndx), con->fd, FDEVENT_IN);
 		break;
 	case CON_STATE_WRITE:
 		/* request write-fdevent only if we really need it
@@ -1790,7 +1802,7 @@ int connection_state_machine(server *srv, connection *con) {
 		if (!chunkqueue_is_empty(con->write_queue) &&
 		    (con->is_writable == 0) &&
 		    (con->traffic_limit_reached == 0)) {
-			fdevent_event_add(srv->ev, &(con->fde_ndx), con->fd, FDEVENT_OUT);
+			fdevent_event_set(srv->ev, &(con->fde_ndx), con->fd, FDEVENT_OUT);
 		} else {
 			fdevent_event_del(srv->ev, &(con->fde_ndx), con->fd);
 		}
