@@ -1,5 +1,5 @@
-#include "fdevent.h"
-#include "buffer.h"
+#include "base.h"
+#include "log.h"
 
 #include <sys/types.h>
 
@@ -9,66 +9,68 @@
 #include <errno.h>
 #include <stdio.h>
 #include <fcntl.h>
+#include <assert.h>
 
 
-fdevents *fdevent_init(size_t maxfds, fdevent_handler_t type) {
+fdevents *fdevent_init(server *srv, size_t maxfds, fdevent_handler_t type) {
 	fdevents *ev;
 
 	ev = calloc(1, sizeof(*ev));
+	ev->srv = srv;
 	ev->fdarray = calloc(maxfds, sizeof(*ev->fdarray));
 	ev->maxfds = maxfds;
 
 	switch(type) {
 	case FDEVENT_HANDLER_POLL:
 		if (0 != fdevent_poll_init(ev)) {
-			fprintf(stderr, "%s.%d: event-handler poll failed\n",
-				__FILE__, __LINE__);
+			log_error_write(ev->srv, __FILE__, __LINE__, "S",
+				"event-handler poll failed");
 
 			return NULL;
 		}
-		break;
+		return ev;
 	case FDEVENT_HANDLER_SELECT:
 		if (0 != fdevent_select_init(ev)) {
-			fprintf(stderr, "%s.%d: event-handler select failed\n",
-				__FILE__, __LINE__);
+			log_error_write(ev->srv, __FILE__, __LINE__, "S",
+				"event-handler select failed");
 			return NULL;
 		}
-		break;
-	case FDEVENT_HANDLER_LINUX_RTSIG:
-		if (0 != fdevent_linux_rtsig_init(ev)) {
-			fprintf(stderr, "%s.%d: event-handler linux-rtsig failed, try to set server.event-handler = \"poll\" or \"select\"\n",
-				__FILE__, __LINE__);
-			return NULL;
-		}
-		break;
+		return ev;
 	case FDEVENT_HANDLER_LINUX_SYSEPOLL:
 		if (0 != fdevent_linux_sysepoll_init(ev)) {
-			fprintf(stderr, "%s.%d: event-handler linux-sysepoll failed, try to set server.event-handler = \"poll\" or \"select\"\n",
-				__FILE__, __LINE__);
+			log_error_write(ev->srv, __FILE__, __LINE__, "S",
+				"event-handler linux-sysepoll failed, try to set server.event-handler = \"poll\" or \"select\"");
 			return NULL;
 		}
-		break;
+		return ev;
 	case FDEVENT_HANDLER_SOLARIS_DEVPOLL:
 		if (0 != fdevent_solaris_devpoll_init(ev)) {
-			fprintf(stderr, "%s.%d: event-handler solaris-devpoll failed, try to set server.event-handler = \"poll\" or \"select\"\n",
-				__FILE__, __LINE__);
+			log_error_write(ev->srv, __FILE__, __LINE__, "S",
+				"event-handler solaris-devpoll failed, try to set server.event-handler = \"poll\" or \"select\"");
 			return NULL;
 		}
-		break;
+		return ev;
 	case FDEVENT_HANDLER_FREEBSD_KQUEUE:
 		if (0 != fdevent_freebsd_kqueue_init(ev)) {
-			fprintf(stderr, "%s.%d: event-handler freebsd-kqueue failed, try to set server.event-handler = \"poll\" or \"select\"\n",
-				__FILE__, __LINE__);
+			log_error_write(ev->srv, __FILE__, __LINE__, "S",
+				"event-handler freebsd-kqueue failed, try to set server.event-handler = \"poll\" or \"select\"");
 			return NULL;
 		}
+		return ev;
+	case FDEVENT_HANDLER_LIBEV:
+		if (0 != fdevent_libev_init(ev)) {
+			log_error_write(ev->srv, __FILE__, __LINE__, "S",
+				"event-handler libev failed, try to set server.event-handler = \"poll\" or \"select\"");
+			return NULL;
+		}
+		return ev;
+	case FDEVENT_HANDLER_UNSET:
 		break;
-	default:
-		fprintf(stderr, "%s.%d: event-handler is unknown, try to set server.event-handler = \"poll\" or \"select\"\n",
-			__FILE__, __LINE__);
-		return NULL;
 	}
 
-	return ev;
+	log_error_write(ev->srv, __FILE__, __LINE__, "S",
+		"event-handler is unknown, try to set server.event-handler = \"poll\" or \"select\"");
+	return NULL;
 }
 
 void fdevent_free(fdevents *ev) {
@@ -110,6 +112,8 @@ int fdevent_register(fdevents *ev, int fd, fdevent_handler handler, void *ctx) {
 	fdn->handler = handler;
 	fdn->fd      = fd;
 	fdn->ctx     = ctx;
+	fdn->handler_ctx = NULL;
+	fdn->events  = 0;
 
 	ev->fdarray[fd] = fdn;
 
@@ -118,9 +122,12 @@ int fdevent_register(fdevents *ev, int fd, fdevent_handler handler, void *ctx) {
 
 int fdevent_unregister(fdevents *ev, int fd) {
 	fdnode *fdn;
-        if (!ev) return 0;
+
+	if (!ev) return 0;
 	fdn = ev->fdarray[fd];
 
+	assert(fdn->events == 0);
+
 	fdnode_free(fdn);
 
 	ev->fdarray[fd] = NULL;
@@ -131,17 +138,21 @@ int fdevent_unregister(fdevents *ev, int fd) {
 int fdevent_event_del(fdevents *ev, int *fde_ndx, int fd) {
 	int fde = fde_ndx ? *fde_ndx : -1;
 
+	if (NULL == ev->fdarray[fd]) return 0;
+
 	if (ev->event_del) fde = ev->event_del(ev, fde, fd);
+	ev->fdarray[fd]->events = 0;
 
 	if (fde_ndx) *fde_ndx = fde;
 
 	return 0;
 }
 
-int fdevent_event_add(fdevents *ev, int *fde_ndx, int fd, int events) {
+int fdevent_event_set(fdevents *ev, int *fde_ndx, int fd, int events) {
 	int fde = fde_ndx ? *fde_ndx : -1;
 
-	if (ev->event_add) fde = ev->event_add(ev, fde, fd, events);
+	if (ev->event_set) fde = ev->event_set(ev, fde, fd, events);
+	ev->fdarray[fd]->events = events;
 
 	if (fde_ndx) *fde_ndx = fde;
 
