@@ -653,7 +653,6 @@ static int http_auth_basic_password_compare(server *srv, mod_auth_plugin_data *p
 		 */
 
 		if (password->used < 13 + 1) {
-			fprintf(stderr, "%s.%d\n", __FILE__, __LINE__);
 			return -1;
 		}
 
@@ -664,7 +663,6 @@ static int http_auth_basic_password_compare(server *srv, mod_auth_plugin_data *p
 			char *dollar = NULL;
 
 			if (NULL == (dollar = strchr(password->ptr + 3, '$'))) {
-				fprintf(stderr, "%s.%d\n", __FILE__, __LINE__);
 				return -1;
 			}
 
@@ -672,7 +670,6 @@ static int http_auth_basic_password_compare(server *srv, mod_auth_plugin_data *p
 		}
 
 		if (salt_len > sizeof(salt) - 1) {
-			fprintf(stderr, "%s.%d\n", __FILE__, __LINE__);
 			return -1;
 		}
 
@@ -684,8 +681,6 @@ static int http_auth_basic_password_compare(server *srv, mod_auth_plugin_data *p
 
 		if (0 == strcmp(password->ptr, crypted)) {
 			return 0;
-		} else {
-			fprintf(stderr, "%s.%d\n", __FILE__, __LINE__);
 		}
 
 #endif
@@ -869,7 +864,7 @@ int http_auth_basic_check(server *srv, connection *con, mod_auth_plugin_data *p,
 		if (AUTH_BACKEND_UNSET == p->conf.auth_backend) {
 			log_error_write(srv, __FILE__, __LINE__, "s", "auth.backend is not set");
 		} else {
-			log_error_write(srv, __FILE__, __LINE__, "s", "get_password failed");
+			log_error_write(srv, __FILE__, __LINE__, "ss", "get_password failed, IP:", inet_ntop_cache_get_ip(srv, &(con->dst_addr)));
 		}
 
 		return 0;
@@ -877,7 +872,7 @@ int http_auth_basic_check(server *srv, connection *con, mod_auth_plugin_data *p,
 
 	/* password doesn't match */
 	if (http_auth_basic_password_compare(srv, p, req, username, realm->value, password, pw)) {
-		log_error_write(srv, __FILE__, __LINE__, "sbbss", "password doesn't match for ", con->uri.path, username, ", IP:", inet_ntop_cache_get_ip(srv, &(con->dst_addr)));
+		log_error_write(srv, __FILE__, __LINE__, "sbsBss", "password doesn't match for", con->uri.path, "username:", username, ", IP:", inet_ntop_cache_get_ip(srv, &(con->dst_addr)));
 
 		buffer_free(username);
 		buffer_free(password);
@@ -1138,7 +1133,7 @@ int http_auth_digest_check(server *srv, connection *con, mod_auth_plugin_data *p
 				"digest: digest mismatch", a2, respons);
 		}
 
-		log_error_write(srv, __FILE__, __LINE__, "sss",
+		log_error_write(srv, __FILE__, __LINE__, "ssss",
 				"digest: auth failed for ", username, ": wrong password, IP:", inet_ntop_cache_get_ip(srv, &(con->dst_addr)));
 
 		buffer_free(b);
