@@ -1,4 +1,6 @@
-#define _GNU_SOURCE
+#include "base.h"
+#include "log.h"
+#include "array.h"
 
 #include <sys/types.h>
 
@@ -12,19 +14,12 @@
 #include <stdarg.h>
 #include <stdio.h>
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef HAVE_SYSLOG_H
-#include <syslog.h>
+# include <syslog.h>
 #endif
 
-#include "log.h"
-#include "array.h"
-
 #ifdef HAVE_VALGRIND_VALGRIND_H
-#include <valgrind/valgrind.h>
+# include <valgrind/valgrind.h>
 #endif
 
 #ifndef O_LARGEFILE
@@ -54,62 +49,152 @@ int openDevNull(int fd) {
 	return (tmpfd != -1) ? 0 : -1;
 }
 
+int open_logfile_or_pipe(server *srv, const char* logfile) {
+	int fd;
+
+	if (logfile[0] == '|') {
+#ifdef HAVE_FORK
+		/* create write pipe and spawn process */
+
+		int to_log_fds[2];
+
+		if (pipe(to_log_fds)) {
+			log_error_write(srv, __FILE__, __LINE__, "ss", "pipe failed: ", strerror(errno));
+			return -1;
+		}
+
+		/* fork, execve */
+		switch (fork()) {
+		case 0:
+			/* child */
+			close(STDIN_FILENO);
+
+			/* dup the filehandle to STDIN */
+			if (to_log_fds[0] != STDIN_FILENO) {
+				if (STDIN_FILENO != dup2(to_log_fds[0], STDIN_FILENO)) {
+					log_error_write(srv, __FILE__, __LINE__, "ss",
+						"dup2 failed: ", strerror(errno));
+					exit(-1);
+				}
+				close(to_log_fds[0]);
+			}
+			close(to_log_fds[1]);
+
+#ifndef FD_CLOEXEC
+			{
+				int i;
+				/* we don't need the client socket */
+				for (i = 3; i < 256; i++) {
+					close(i);
+				}
+			}
+#endif
+
+			/* close old stderr */
+			openDevNull(STDERR_FILENO);
+
+			/* exec the log-process (skip the | ) */
+			execl("/bin/sh", "sh", "-c", logfile + 1, NULL);
+			log_error_write(srv, __FILE__, __LINE__, "sss",
+					"spawning log process failed: ", strerror(errno),
+					logfile + 1);
+
+			exit(-1);
+			break;
+		case -1:
+			/* error */
+			log_error_write(srv, __FILE__, __LINE__, "ss", "fork failed: ", strerror(errno));
+			return -1;
+		default:
+			close(to_log_fds[0]);
+			fd = to_log_fds[1];
+			break;
+		}
+
+#else
+		return -1;
+#endif
+	} else if (-1 == (fd = open(logfile, O_APPEND | O_WRONLY | O_CREAT | O_LARGEFILE, 0644))) {
+		log_error_write(srv, __FILE__, __LINE__, "SSSS",
+				"opening errorlog '", logfile,
+				"' failed: ", strerror(errno));
+
+		return -1;
+	}
+
+#ifdef FD_CLOEXEC
+	fcntl(fd, F_SETFD, FD_CLOEXEC);
+#endif
+
+	return fd;
+}
+
+
 /**
  * open the errorlog
  *
- * we have 3 possibilities:
+ * we have 4 possibilities:
  * - stderr (default)
  * - syslog
  * - logfile
+ * - pipe
  *
  * if the open failed, report to the user and die
  *
  */
 
 int log_error_open(server *srv) {
-	int close_stderr = 1;
-
 #ifdef HAVE_SYSLOG_H
 	/* perhaps someone wants to use syslog() */
 	openlog("lighttpd", LOG_CONS | LOG_PID, LOG_DAEMON);
 #endif
-	srv->errorlog_mode = ERRORLOG_STDERR;
+
+	srv->errorlog_mode = ERRORLOG_FD;
+	srv->errorlog_fd = STDERR_FILENO;
 
 	if (srv->srvconf.errorlog_use_syslog) {
 		srv->errorlog_mode = ERRORLOG_SYSLOG;
 	} else if (!buffer_is_empty(srv->srvconf.errorlog_file)) {
 		const char *logfile = srv->srvconf.errorlog_file->ptr;
 
-		if (-1 == (srv->errorlog_fd = open(logfile, O_APPEND | O_WRONLY | O_CREAT | O_LARGEFILE, 0644))) {
-			log_error_write(srv, __FILE__, __LINE__, "SSSS",
-					"opening errorlog '", logfile,
-					"' failed: ", strerror(errno));
-
+		if (-1 == (srv->errorlog_fd = open_logfile_or_pipe(srv, logfile))) {
 			return -1;
 		}
-#ifdef FD_CLOEXEC
-		/* close fd on exec (cgi) */
-		fcntl(srv->errorlog_fd, F_SETFD, FD_CLOEXEC);
-#endif
-		srv->errorlog_mode = ERRORLOG_FILE;
+		srv->errorlog_mode = (logfile[0] == '|') ? ERRORLOG_PIPE : ERRORLOG_FILE;
 	}
 
 	log_error_write(srv, __FILE__, __LINE__, "s", "server started");
 
-#ifdef HAVE_VALGRIND_VALGRIND_H
-	/* don't close stderr for debugging purposes if run in valgrind */
-	if (RUNNING_ON_VALGRIND) close_stderr = 0;
-#endif
-
-	if (srv->errorlog_mode == ERRORLOG_STDERR && srv->srvconf.dont_daemonize) {
+	if (srv->errorlog_mode == ERRORLOG_FD && !srv->srvconf.dont_daemonize) {
 		/* We can only log to stderr in dont-daemonize mode;
 		 * if we do daemonize and no errorlog file is specified, we log into /dev/null
 		 */
-		close_stderr = 0;
+		srv->errorlog_fd = -1;
 	}
 
-	/* move stderr to /dev/null */
-	if (close_stderr) openDevNull(STDERR_FILENO);
+	if (!buffer_is_empty(srv->srvconf.breakagelog_file)) {
+		int breakage_fd;
+		const char *logfile = srv->srvconf.breakagelog_file->ptr;
+
+		if (srv->errorlog_mode == ERRORLOG_FD) {
+			srv->errorlog_fd = dup(STDERR_FILENO);
+#ifdef FD_CLOEXEC
+			fcntl(srv->errorlog_fd, F_SETFD, FD_CLOEXEC);
+#endif
+		}
+
+		if (-1 == (breakage_fd = open_logfile_or_pipe(srv, logfile))) {
+			return -1;
+		}
+
+		if (STDERR_FILENO != breakage_fd) {
+			dup2(breakage_fd, STDERR_FILENO);
+			close(breakage_fd);
+		}
+	} else if (!srv->srvconf.dont_daemonize) {
+		/* move stderr to /dev/null */
+		openDevNull(STDERR_FILENO);
+	}
 	return 0;
 }
 
@@ -122,7 +207,7 @@ int log_error_open(server *srv) {
  */
 
 int log_error_cycle(server *srv) {
-	/* only cycle if we are not in syslog-mode */
+	/* only cycle if the error log is a file */
 
 	if (srv->errorlog_mode == ERRORLOG_FILE) {
 		const char *logfile = srv->srvconf.errorlog_file->ptr;
@@ -130,7 +215,7 @@ int log_error_cycle(server *srv) {
 
 		int new_fd;
 
-		if (-1 == (new_fd = open(logfile, O_APPEND | O_WRONLY | O_CREAT | O_LARGEFILE, 0644))) {
+		if (-1 == (new_fd = open_logfile_or_pipe(srv, logfile))) {
 			/* write to old log */
 			log_error_write(srv, __FILE__, __LINE__, "SSSSS",
 					"cycling errorlog '", logfile,
@@ -158,16 +243,21 @@ int log_error_cycle(server *srv) {
 
 int log_error_close(server *srv) {
 	switch(srv->errorlog_mode) {
+	case ERRORLOG_PIPE:
 	case ERRORLOG_FILE:
-		close(srv->errorlog_fd);
+	case ERRORLOG_FD:
+		if (-1 != srv->errorlog_fd) {
+			/* don't close STDERR */
+			if (STDERR_FILENO != srv->errorlog_fd)
+				close(srv->errorlog_fd);
+			srv->errorlog_fd = -1;
+		}
 		break;
 	case ERRORLOG_SYSLOG:
 #ifdef HAVE_SYSLOG_H
 		closelog();
 #endif
 		break;
-	case ERRORLOG_STDERR:
-		break;
 	}
 
 	return 0;
@@ -177,8 +267,10 @@ int log_error_write(server *srv, const char *filename, unsigned int line, const
 	va_list ap;
 
 	switch(srv->errorlog_mode) {
+	case ERRORLOG_PIPE:
 	case ERRORLOG_FILE:
-	case ERRORLOG_STDERR:
+	case ERRORLOG_FD:
+		if (-1 == srv->errorlog_fd) return 0;
 		/* cache the generated timestamp */
 		if (srv->cur_ts != srv->last_generated_debug_ts) {
 			buffer_prepare_copy(srv->ts_debug_str, 255);
@@ -270,14 +362,12 @@ int log_error_write(server *srv, const char *filename, unsigned int line, const
 	va_end(ap);
 
 	switch(srv->errorlog_mode) {
+	case ERRORLOG_PIPE:
 	case ERRORLOG_FILE:
+	case ERRORLOG_FD:
 		buffer_append_string_len(srv->errorlog_buf, CONST_STR_LEN("\n"));
 		write(srv->errorlog_fd, srv->errorlog_buf->ptr, srv->errorlog_buf->used - 1);
 		break;
-	case ERRORLOG_STDERR:
-		buffer_append_string_len(srv->errorlog_buf, CONST_STR_LEN("\n"));
-		write(STDERR_FILENO, srv->errorlog_buf->ptr, srv->errorlog_buf->used - 1);
-		break;
 	case ERRORLOG_SYSLOG:
 		syslog(LOG_ERR, "%s", srv->errorlog_buf->ptr);
 		break;
