@@ -24,7 +24,7 @@ documentation and/or software.
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 #ifndef USE_OPENSSL
@@ -52,9 +52,9 @@ documentation and/or software.
 #define S43 15
 #define S44 21
 
-static void MD5Transform (UINT4 [4], unsigned char [64]);
+static void MD5Transform (UINT4 [4], const unsigned char [64]);
 static void Encode (unsigned char *, UINT4 *, unsigned int);
-static void Decode (UINT4 *, unsigned char *, unsigned int);
+static void Decode (UINT4 *, const unsigned char *, unsigned int);
 
 #ifdef HAVE_MEMCPY
 #define MD5_memcpy(output, input, len) memcpy((output), (input), (len))
@@ -126,12 +126,13 @@ MD5_CTX *context;                                        /* context */
   operation, processing another message block, and updating the
   context.
  */
-void MD5_Update (context, input, inputLen)
+void MD5_Update (context, _input, inputLen)
 MD5_CTX *context;                                        /* context */
-unsigned char *input;                                /* input block */
+const void *_input;                                /* input block */
 unsigned int inputLen;                     /* length of input block */
 {
   unsigned int i, ndx, partLen;
+  const unsigned char *input = (const unsigned char*) _input;
 
   /* Compute number of bytes mod 64 */
   ndx = (unsigned int)((context->count[0] >> 3) & 0x3F);
@@ -200,7 +201,7 @@ MD5_CTX *context;                                       /* context */
  */
 static void MD5Transform (state, block)
 UINT4 state[4];
-unsigned char block[64];
+const unsigned char block[64];
 {
   UINT4 a = state[0], b = state[1], c = state[2], d = state[3], x[16];
 
@@ -313,7 +314,7 @@ unsigned int len;
  */
 static void Decode (output, input, len)
 UINT4 *output;
-unsigned char *input;
+const unsigned char *input;
 unsigned int len;
 {
   unsigned int i, j;
