@@ -1,14 +1,3 @@
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#include <fcntl.h>
-#include <unistd.h>
-#include <ctype.h>
-#include <stdlib.h>
-#include <string.h>
-#include <errno.h>
-#include <time.h>
-
 #include "base.h"
 #include "log.h"
 #include "buffer.h"
@@ -20,6 +9,17 @@
 #include "crc32.h"
 #include "etag.h"
 
+#include <sys/types.h>
+#include <sys/stat.h>
+
+#include <fcntl.h>
+#include <unistd.h>
+#include <ctype.h>
+#include <stdlib.h>
+#include <string.h>
+#include <errno.h>
+#include <time.h>
+
 #if defined HAVE_ZLIB_H && defined HAVE_LIBZ
 # define USE_ZLIB
 # include <zlib.h>
@@ -42,7 +42,7 @@
 #define HTTP_ACCEPT_ENCODING_BZIP2    BV(4)
 
 #ifdef __WIN32
-#define mkdir(x,y) mkdir(x)
+# define mkdir(x,y) mkdir(x)
 #endif
 
 typedef struct {
@@ -104,7 +104,7 @@ FREE_FUNC(mod_compress_free) {
 }
 
 /* 0 on success, -1 for error */
-int mkdir_recursive(char *dir) {
+static int mkdir_recursive(char *dir) {
 	char *p = dir;
 
 	if (!dir || !dir[0])
@@ -126,7 +126,7 @@ int mkdir_recursive(char *dir) {
 }
 
 /* 0 on success, -1 for error */
-int mkdir_for_file(char *filename) {
+static int mkdir_for_file(char *filename) {
 	char *p = filename;
 
 	if (!filename || !filename[0])
@@ -661,6 +661,7 @@ PHYSICALPATH_FUNC(mod_compress_physical) {
 	off_t max_fsize;
 	stat_cache_entry *sce = NULL;
 	buffer *mtime = NULL;
+	buffer *content_type;
 
 	if (con->mode != DIRECT || con->http_status) return HANDLER_GO_ON;
 
@@ -713,6 +714,15 @@ PHYSICALPATH_FUNC(mod_compress_physical) {
 	if (sce->st.st_size < 128) return HANDLER_GO_ON;
 
 	/* check if mimetype is in compress-config */
+	content_type = 0;
+	if (sce->content_type->ptr) {
+		char *c;
+		if ( (c = strchr(sce->content_type->ptr, ';')) != 0) {
+			content_type = srv->tmp_buf;
+			buffer_copy_string_len(content_type, sce->content_type->ptr, c - sce->content_type->ptr);
+		}
+	}
+
 	for (m = 0; m < p->conf.compress->used; m++) {
 		data_string *compress_ds = (data_string *)p->conf.compress->data[m];
 
@@ -722,7 +732,8 @@ PHYSICALPATH_FUNC(mod_compress_physical) {
 			return HANDLER_GO_ON;
 		}
 
-		if (buffer_is_equal(compress_ds->value, sce->content_type)) {
+		if (buffer_is_equal(compress_ds->value, sce->content_type)
+		    || (content_type && buffer_is_equal(compress_ds->value, content_type))) {
 			/* mimetype found */
 			data_string *ds;
 
@@ -733,6 +744,7 @@ PHYSICALPATH_FUNC(mod_compress_physical) {
 				int accept_encoding = 0;
 				char *value = ds->value->ptr;
 				int matched_encodings = 0;
+				int use_etag = sce->etag != NULL && sce->etag->ptr != NULL;
 
 				/* get client side support encodings */
 #ifdef USE_ZLIB
@@ -759,12 +771,14 @@ PHYSICALPATH_FUNC(mod_compress_physical) {
 					mtime = strftime_cache_get(srv, sce->st.st_mtime);
 
 					/* try matching original etag of uncompressed version */
-					etag_mutate(con->physical.etag, sce->etag);
-					if (HANDLER_FINISHED == http_response_handle_cachable(srv, con, mtime)) {
-						response_header_overwrite(srv, con, CONST_STR_LEN("Content-Type"), CONST_BUF_LEN(sce->content_type));
-						response_header_overwrite(srv, con, CONST_STR_LEN("Last-Modified"), CONST_BUF_LEN(mtime));
-						response_header_overwrite(srv, con, CONST_STR_LEN("ETag"), CONST_BUF_LEN(con->physical.etag));
-						return HANDLER_FINISHED;
+					if (use_etag) {
+						etag_mutate(con->physical.etag, sce->etag);
+						if (HANDLER_FINISHED == http_response_handle_cachable(srv, con, mtime)) {
+							response_header_overwrite(srv, con, CONST_STR_LEN("Content-Type"), CONST_BUF_LEN(sce->content_type));
+							response_header_overwrite(srv, con, CONST_STR_LEN("Last-Modified"), CONST_BUF_LEN(mtime));
+							response_header_overwrite(srv, con, CONST_STR_LEN("ETag"), CONST_BUF_LEN(con->physical.etag));
+							return HANDLER_FINISHED;
+						}
 					}
 
 					/* select best matching encoding */
@@ -779,22 +793,26 @@ PHYSICALPATH_FUNC(mod_compress_physical) {
 						compression_name = dflt_deflate;
 					}
 
-					/* try matching etag of compressed version */
-					buffer_copy_string_buffer(srv->tmp_buf, sce->etag);
-					buffer_append_string_len(srv->tmp_buf, CONST_STR_LEN("-"));
-					buffer_append_string(srv->tmp_buf, compression_name);
-					etag_mutate(con->physical.etag, srv->tmp_buf);
+					if (use_etag) {
+						/* try matching etag of compressed version */
+						buffer_copy_string_buffer(srv->tmp_buf, sce->etag);
+						buffer_append_string_len(srv->tmp_buf, CONST_STR_LEN("-"));
+						buffer_append_string(srv->tmp_buf, compression_name);
+						etag_mutate(con->physical.etag, srv->tmp_buf);
+					}
 
 					if (HANDLER_FINISHED == http_response_handle_cachable(srv, con, mtime)) {
 						response_header_overwrite(srv, con, CONST_STR_LEN("Content-Encoding"), compression_name, strlen(compression_name));
 						response_header_overwrite(srv, con, CONST_STR_LEN("Content-Type"), CONST_BUF_LEN(sce->content_type));
 						response_header_overwrite(srv, con, CONST_STR_LEN("Last-Modified"), CONST_BUF_LEN(mtime));
-						response_header_overwrite(srv, con, CONST_STR_LEN("ETag"), CONST_BUF_LEN(con->physical.etag));
+						if (use_etag) {
+							response_header_overwrite(srv, con, CONST_STR_LEN("ETag"), CONST_BUF_LEN(con->physical.etag));
+						}
 						return HANDLER_FINISHED;
 					}
 
 					/* deflate it */
-					if (p->conf.compress_cache_dir->used) {
+					if (use_etag && p->conf.compress_cache_dir->used) {
 						if (0 != deflate_file_to_file(srv, con, p, con->physical.path, sce, compression_type))
 							return HANDLER_GO_ON;
 					} else {
@@ -803,7 +821,9 @@ PHYSICALPATH_FUNC(mod_compress_physical) {
 					}
 					response_header_overwrite(srv, con, CONST_STR_LEN("Content-Encoding"), compression_name, strlen(compression_name));
 					response_header_overwrite(srv, con, CONST_STR_LEN("Last-Modified"), CONST_BUF_LEN(mtime));
-					response_header_overwrite(srv, con, CONST_STR_LEN("ETag"), CONST_BUF_LEN(con->physical.etag));
+					if (use_etag) {
+						response_header_overwrite(srv, con, CONST_STR_LEN("ETag"), CONST_BUF_LEN(con->physical.etag));
+					}
 					response_header_overwrite(srv, con, CONST_STR_LEN("Content-Type"), CONST_BUF_LEN(sce->content_type));
 					/* let mod_staticfile handle the cached compressed files, physical path was modified */
 					return p->conf.compress_cache_dir->used ? HANDLER_GO_ON : HANDLER_FINISHED;
@@ -815,6 +835,7 @@ PHYSICALPATH_FUNC(mod_compress_physical) {
 	return HANDLER_GO_ON;
 }
 
+int mod_compress_plugin_init(plugin *p);
 int mod_compress_plugin_init(plugin *p) {
 	p->version     = LIGHTTPD_VERSION_ID;
 	p->name        = buffer_init_string("compress");
