@@ -112,7 +112,7 @@ typedef struct {
 
 
 /* ok, we need a prototype */
-static handler_t proxy_handle_fdevent(void *s, void *ctx, int revents);
+static handler_t proxy_handle_fdevent(server *srv, void *ctx, int revents);
 
 static handler_ctx * handler_ctx_init() {
 	handler_ctx * hctx;
@@ -349,6 +349,10 @@ static void proxy_connection_close(server *srv, handler_ctx *hctx) {
 		srv->cur_fds--;
 	}
 
+	if (hctx->host) {
+		hctx->host->usage--;
+	}
+
 	handler_ctx_free(hctx);
 	con->plugin_ctx[p->id] = NULL;
 }
@@ -794,7 +798,7 @@ static handler_t proxy_write_request(server *srv, handler_ctx *hctx) {
 
 				/* connection is in progress, wait for an event and call getsockopt() below */
 
-				fdevent_event_add(srv->ev, &(hctx->fde_ndx), hctx->fd, FDEVENT_OUT);
+				fdevent_event_set(srv->ev, &(hctx->fde_ndx), hctx->fd, FDEVENT_OUT);
 
 				return HANDLER_WAIT_FOR_EVENT;
 			case -1:
@@ -848,20 +852,20 @@ static handler_t proxy_write_request(server *srv, handler_ctx *hctx) {
 		if (-1 == ret) { /* error on our side */
 			log_error_write(srv, __FILE__, __LINE__, "ssd", "write failed:", strerror(errno), errno);
 
-			return HANDLER_WAIT_FOR_EVENT;
+			return HANDLER_ERROR;
 		} else if (-2 == ret) { /* remote close */
 			log_error_write(srv, __FILE__, __LINE__, "ssd", "write failed, remote connection close:", strerror(errno), errno);
 
-			return HANDLER_WAIT_FOR_EVENT;
+			return HANDLER_ERROR;
 		}
 
 		if (hctx->wb->bytes_out == hctx->wb->bytes_in) {
 			proxy_set_state(srv, hctx, PROXY_STATE_READ);
 
 			fdevent_event_del(srv->ev, &(hctx->fde_ndx), hctx->fd);
-			fdevent_event_add(srv->ev, &(hctx->fde_ndx), hctx->fd, FDEVENT_IN);
+			fdevent_event_set(srv->ev, &(hctx->fde_ndx), hctx->fd, FDEVENT_IN);
 		} else {
-			fdevent_event_add(srv->ev, &(hctx->fde_ndx), hctx->fd, FDEVENT_OUT);
+			fdevent_event_set(srv->ev, &(hctx->fde_ndx), hctx->fd, FDEVENT_OUT);
 
 			return HANDLER_WAIT_FOR_EVENT;
 		}
@@ -956,7 +960,7 @@ SUBREQUEST_FUNC(mod_proxy_handle_subrequest) {
 
 		return HANDLER_WAIT_FOR_FD;
 	case HANDLER_WAIT_FOR_EVENT:
-		return HANDLER_WAIT_FOR_EVENT;
+		break;
 	case HANDLER_WAIT_FOR_FD:
 		return HANDLER_WAIT_FOR_FD;
 	default:
@@ -970,8 +974,7 @@ SUBREQUEST_FUNC(mod_proxy_handle_subrequest) {
 	}
 }
 
-static handler_t proxy_handle_fdevent(void *s, void *ctx, int revents) {
-	server      *srv  = (server *)s;
+static handler_t proxy_handle_fdevent(server *srv, void *ctx, int revents) {
 	handler_ctx *hctx = ctx;
 	connection  *con  = hctx->remote_conn;
 	plugin_data *p    = hctx->plugin_data;
@@ -989,8 +992,6 @@ static handler_t proxy_handle_fdevent(void *s, void *ctx, int revents) {
 		case 0:
 			break;
 		case 1:
-			hctx->host->usage--;
-
 			/* we are done */
 			proxy_connection_close(srv, hctx);
 
@@ -1047,17 +1048,41 @@ static handler_t proxy_handle_fdevent(void *s, void *ctx, int revents) {
 			 *
 			 */
 
-			proxy_connection_close(srv, hctx);
-			joblist_append(srv, con);
+			if (hctx->host) {
+				hctx->host->is_disabled = 1;
+				hctx->host->disable_ts = srv->cur_ts;
+				log_error_write(srv, __FILE__, __LINE__,  "sbdd", "proxy-server disabled:",
+						hctx->host->host,
+						hctx->host->port,
+						hctx->fd);
 
-			con->http_status = 503;
-			con->mode = DIRECT;
+				/* disable this server */
+				hctx->host->is_disabled = 1;
+				hctx->host->disable_ts = srv->cur_ts;
+
+				proxy_connection_close(srv, hctx);
+
+				/* reset the enviroment and restart the sub-request */
+				buffer_reset(con->physical.path);
+				con->mode = DIRECT;
+
+				joblist_append(srv, con);
+			} else {
+				proxy_connection_close(srv, hctx);
+				joblist_append(srv, con);
+
+				con->mode = DIRECT;
+				con->http_status = 503;
+			}
 
 			return HANDLER_FINISHED;
 		}
 
-		con->file_finished = 1;
+		if (!con->file_finished) {
+			http_chunk_append_mem(srv, con, NULL, 0);
+		}
 
+		con->file_finished = 1;
 		proxy_connection_close(srv, hctx);
 		joblist_append(srv, con);
 	} else if (revents & FDEVENT_ERR) {
@@ -1065,6 +1090,7 @@ static handler_t proxy_handle_fdevent(void *s, void *ctx, int revents) {
 
 		log_error_write(srv, __FILE__, __LINE__, "sd", "proxy-FDEVENT_ERR, but no HUP", revents);
 
+		con->file_finished = 1;
 		joblist_append(srv, con);
 		proxy_connection_close(srv, hctx);
 	}
